controller

package
v0.0.0-...-f1d5a52 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 10, 2018 License: BSD-3-Clause Imports: 28 Imported by: 0

Documentation

Index

Constants

const (

	// BGPPeersSyncFailed is the reason used on events to denote a failed sync
	BGPPeersSyncFailed = "BGPPeersSyncFailed"

	// BGPPeersSyncSuccess is the reason used on events to denote a successful sync
	BGPPeersSyncSuccess = "BGPPeersSyncSuccess"
)

Variables

This section is empty.

Functions

func Start

func Start(c Config, stopCh <-chan struct{}) error

Start starts the Remesher controller that watches for node events and reconcile the BGPPeers in Calico The controller uses leader election to make sure a single instance is handling events

Types

type Config

type Config struct {
	CalicoClient         calico.BGPPeerInterface
	KubeClient           kubernetes.Interface
	Logger               *logrus.Entry
	Namespace            string
	NumWorkers           int
	NeighborhoodLabel    string
	MetricsRegisterer    prometheus.Registerer
	LeaderElectionConfig *leaderelection.LeaderElectionConfig
	ResyncInterval       time.Duration
	RecordEvents         bool
}

Config is a container for the Controller configuration options

Jump to