Documentation
¶
Index ¶
Constants ¶
const ( // BGPPeersSyncFailed is the reason used on events to denote a failed sync BGPPeersSyncFailed = "BGPPeersSyncFailed" // BGPPeersSyncSuccess is the reason used on events to denote a successful sync BGPPeersSyncSuccess = "BGPPeersSyncSuccess" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
CalicoClient calico.BGPPeerInterface
KubeClient kubernetes.Interface
Logger *logrus.Entry
Namespace string
NumWorkers int
NeighborhoodLabel string
MetricsRegisterer prometheus.Registerer
LeaderElectionConfig *leaderelection.LeaderElectionConfig
ResyncInterval time.Duration
RecordEvents bool
}
Config is a container for the Controller configuration options
Click to show internal directories.
Click to hide internal directories.